@@ -66,7 +66,10 @@ def print_setuptools_ver():
         sys.stderr.flush()
         pass
 
-def print_py_pkg_ver(pkgname):
+def print_py_pkg_ver(pkgname, modulename=None):
+    if modulename is None:
+        modulename = pkgname
+
     print
     try:
         import pkg_resources
@@ -82,6 +85,17 @@ def print_py_pkg_ver(pkgname):
         traceback.print_exc(file=sys.stderr)
         sys.stderr.flush()
         pass
+    try:
+        __import__(modulename)
+    except ImportError:
+        pass
+    else:
+        modobj = sys.modules.get(modulename)
+        print pkgname + ' module: ' + str(modobj)
+        try:
+            print pkgname + ' __version__: ' + str(modobj.__version__)
+        except AttributeError:
+            pass
 
 print_platform()
 
@@ -94,6 +108,8 @@ print_stdout(['cryptest', 'V'])
 print_stdout(['darcs', '--version'])
 print_stdout(['darcs', '--exact-version'], label='darcs-exact-version')
 print_stdout(['7za'])
+print_stdout(['flappclient', '--version'])
+print_stdout(['valgrind', '--version'])
 
 print_as_ver()
 
@@ -104,3 +120,5 @@ print_py_pkg_ver('trialcoverage')
 print_py_pkg_ver('setuptools_trial')
 print_py_pkg_ver('setuptools_darcs')
 print_py_pkg_ver('darcsver')
+print_py_pkg_ver('Twisted', 'twisted')
+print_py_pkg_ver('TwistedCore', 'twisted.python')
