@@ -1,19 +1,22 @@
-
 #include <Python.h>
 
-//#include "publickey/ecdsamodule.hpp"
+#include "publickey/ecdsamodule.hpp"
 #include "publickey/rsamodule.hpp"
 #include "hash/sha256module.hpp"
 #include "cipher/aesmodule.hpp"
 
 /* from Crypto++ */
+#ifdef DISABLE_EMBEDDED_CRYPTOPP
 #include <cryptopp/config.h>
+#else
+#include <embeddedcryptopp/config.h>
+#endif
 
 PyDoc_STRVAR(_pycryptopp__doc__,
 "_pycryptopp -- Python wrappers for a few algorithms from Crypto++\n\
 \n\
 from pycryptopp import publickey\n\
-#from pycryptopp.publickey import ecdsa\n\
+from pycryptopp.publickey import ecdsa\n\
 from pycryptopp.publickey import rsa\n\
 from pycryptopp import cipher\n\
 from pycryptopp.cipher import aes\n\
@@ -52,9 +55,8 @@ init_pycryptopp(void) {
         return;
 
 
-    //init_ecdsa(module);
+    init_ecdsa(module);
     init_rsa(module);
     init_sha256(module);
     init_aes(module);
 }
-
